<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class Branch {

  private $branchService;

  public function __construct(\App\Service\Branch $branchService) {
      $this->branchService = $branchService;
  }

  public function getUnits(Request $request, Response $response) {
    try {
      $params = $request->getQueryParams();
      $search = isset($params['search']) ? strval(strtoupper($params['search'])) : 'T';
      $units  = $this->branchService->getUnits($search);

      if(empty($units)) {
        throw new \Exception('Nenhuma filial encontrada.');
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => '',
        'data'    => $units,
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => count($units),
          'page' => $params['page'] ?? 1
        ]
      ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function blockStores(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $this->branchService->blockStores($params);

      if (count($params['CDLOJA']) === 1) {
        $message = 'Loja bloqueada com sucesso.';
      } else {
        $message = 'Lojas bloqueadas com sucesso.';
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => $message,
        'data'    => [],
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => '',
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => 'Erro ao tentar bloquear loja(s). Detalhes: '.$e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function getBlockedProductUnits(Request $request, Response $response) {
    try {
      $params = $request->getQueryParams();
      $search = isset($params['search']) ? strval(strtoupper($params['search'])) : 'T';
      $units = $this->branchService->getBlockedProductUnits($search);

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => '',
        'data'    => $units,
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => count($units),
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function getAvailableProductsByUnit(Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $getAvailableProductsByUnit = $this->branchService->getAvailableProductsByUnit($params);

      if(empty($getAvailableProductsByUnit)) {
        throw new \Exception('Não há produtos disponíveis para bloqueio.');
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => '',
        'data'    => $getAvailableProductsByUnit,
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => count($getAvailableProductsByUnit),
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => $e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function blockProducts (Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $this->branchService->blockProducts($params);

      if (count($params['CDPRODUTO']) === 1) {
        $message = 'Produto bloqueado com sucesso.';
      } else {
        $message = 'Produtos bloqueados com sucesso.';
      }

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => $message,
        'data'    => [],
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => '',
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => 'Erro ao tentar bloquear produto(s). Detalhes: '.$e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }

  public function unblockProducts (Request $request, Response $response) {
    try {
      $params = $request->getParsedBody();
      $this->branchService->unblockProducts($params);

      $response->getBody()->write(json_encode([
        'error'   => false,
        'message' => 'Produto(s) desbloqueado(s) com sucesso.',
        'data'    => [],
        'pagination' => [
          'limit' => $params['limit'] ?? 50,
          'total' => '',
          'page' => $params['page'] ?? 1
      ]
    ]));
      return $response->withHeader('Content-Type', 'application/json');
    } catch (\Exception $e) {
      $response->getBody()->write(json_encode([
        'error'   => true,
        'message' => 'Erro ao tentar bloquear produto(s). Detalhes: '.$e->getMessage(),
        'data'    => []
      ]));
      return $response;
    }
  }
}